@@ -50,6 +50,7 @@ build="0"
 user=""
 app_path="./"
 passed_time=0
+passed_time2=0
 DelayStartTime=10
 last_beep=0
 #graphBlocks=0
@@ -58,29 +59,27 @@ OfflineMode="False"
 DelayStart=0
 interval=0
 GraphStart=0
+#GraphStartHours=0
+#GraphStartMinutes=0
+AlarmTimeSec=0 #absolute alarm time in seconds
+AlarmDate=0
+AlarmHour=-1
+AlarmMinute=-1
+AlarmIsSet=False
+AlarmIsActive=False
+AlarmTimeWindow=30 #in minutes
+AlarmID=-1 #cookie for communication to system
+#EventSetAlarm=-1
+#EventEffectiveAlarm=-1
 
 #arrays, indexes, lenghts
 #arrDataLen=4680 #(1 value/10sec for 13h), 6*13*60
 arrDataLen=8640 #(1 value/10sec for 24h), 6*24*60
-arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen] #[0]=time [1]=X, [2]=Y, [3]=X deriv, [4]=Y deriv
+##old             [0]=time            [1]=X,                [2]=Y,                [3]=X derivation,[4]=Y derivation
+#             [0]=time            [1]=X,                [2]=Y,                [3]=X+Y derivation, [4]=Time since last movement over treshhold, [5]=event
+arrData=[[0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen, [0]*arrDataLen,        [0]*arrDataLen ,             [0]*arrDataLen] 
 arrDataTemp=[0, 0, 0] #[0]=unused, [1]=X, [2]=Y
 arrDataIndex=0
 arrLogFiles=[]
 arrLogFilesIndex=0
 LogFileSelectedDate=""
-
-##Explanations of algorithm and array structure
-## Array arrData
-##[0]       [1]  [2]   [3]    [4]    [5]
-##[time0][X0][Y0][dX0][dY0][Mov0]
-##[time1][X1][Y1][dX1][dY1][Mov1]
-##[time2][X2][Y2][dX2][dY2][Mov2]
-##[time3][X3][Y3][dX3][dY3][Mov3]
-##[time4][X4][Y4][dX4][dY4][Mov4]
-##[time5][X5][Y5][dX5][dY5][Mov5]
-##
-##time=string "hh:mm:ss"
-##dX0=X5-X0
-##dY0=Y5-Y0
-##Mov0=1 if(abs(dX0)+abs(dY0)>trigger),  else 0
-##last_ =saves the index of the last movement 
