@@ -34,6 +34,7 @@ from Ui_RecordWindow import *
 from Ui_ViewWindow import *
 from Ui_ConfigWindow import *
 from Ui_DateWindow import *
+from Ui_AlarmTimeWindow import *
 
 
 
@@ -43,7 +44,7 @@ from Ui_DateWindow import *
 # Main function
 ###########################################################################
 def main():
-    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow
+    global app,  StartWindow,  RecordWindow,  ViewWindow ,  ConfigWindow,  DateWindow,  AlarmTimeWindow
     global config
     global RecordWindowGraph
    
@@ -92,17 +93,21 @@ def main():
     ConfigWindow = frmConfigWindow(StartWindow)
     ViewWindow = frmViewWindow(StartWindow)
     DateWindow = frmDateWindow(ViewWindow)
+    AlarmTimeWindow = frmAlarmTimeWindow(StartWindow)
     
     # Hide SubWindows at first
     RecordWindow.hide()
     ViewWindow.hide()
     ConfigWindow.hide()
+    AlarmTimeWindow.hide()
+    DateWindow.hide()
     
     
     #get user name for in log files
     if(data.user==""):
         EditUserName()
 
+    Show_passed_time("Application fully loaded", 1)
     sys.exit(app.exec_())
 
 
@@ -123,13 +128,21 @@ def EditUserName():
 ###########################################################################
 #  Gets called every second,
 ###########################################################################
-def TimerLoop():
+def TimerLoop(): #(interval: sampling*sample_smoothing*value_smoothing)
     global RecordWindowGraph    
 #    Show_passed_time("TimerLoop start")
-    r=GetSensorData() #(interval: sampling*sample_smoothing*value_smoothing)
-    if(r==1):
+    r=GetSensorData() 
+    if(r==1): #new data got added to array
+        
+        ProcessData()      
+     
+        r=ProcessAlarm()
+#        if(r==1): #activated Alarm
+#            WriteIntoLogFile()
+#            StopMeasurement()
+#            return
+            
         WriteIntoLogFile()
-        ProcessData() 
         
         Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
         data.GraphStart=max(Pixels-779, 0)
@@ -150,19 +163,70 @@ def TimerLoop():
 
 
 
+def ProcessAlarm():
+    #add note to array for graph
+    if(data.arrDataIndex==0 and data.AlarmIsSet==True): #do only on first time and if alarm is set
+#        print "first loop run",  data.arrData[0][0]
+        t=string.split(data.arrData[0][0],  ":")
+        now=int(t[0])*3600+int(t[1])*60
+        al=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60
+        alarmdiff=al-now
+        if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
+            alarmdiff=alarmdiff+86400
+        
+        i=alarmdiff/10
+        
+        if(i<data.arrDataLen): 
+            data.arrData[5][i]="Alarm Time Window End" #Last oportunity for alarm
+#            print "Set Alarm Time Window End:",  i
+#            if(i-data.AlarmTimeWindow*6>0):
+            i=max(i-6*data.AlarmTimeWindow, 0)
+            data.arrData[5][i]="Alarm Time Window Begin" #First oportunity for alarm
+#            print "Set Alarm Time Window Begin:",  i
+        else:
+            print "EventSetAlarm is out of range"
+            
+#        print "Set Alarm time (index) to:",  i-data.AlarmTimeWindow*6,  "-",  i,  data.AlarmTimeWindow
+  
+    i=data.arrDataIndex-data.derivation            
+    if(i>1): peak=data.arrData[3][i-1]
+    else: peak=0
+#    print "Peak:",  peak,  data.trigger
+    if(peak>data.trigger): #Movement, check if time for alarm        
+        Now=int(strftime("%H", time.localtime()))*60+int(strftime("%M", time.localtime()))
+        Al=int(data.AlarmHour)*60+int(data.AlarmMinute)
+#        print "Now:", Now,  "Alarm:", Al,  "AlarmTimeWindow:", data.AlarmTimeWindow, "AlarmIsSet:", data.AlarmIsSet, "AlarmIsActive:",  data.AlarmIsActive
+        if(data.AlarmIsSet==True and data.AlarmIsActive==False and  Now>(Al-data.AlarmTimeWindow) and Now<=Al): #set Alarm off
+            print "************ ALARM ALARM *********************"
+            data.AlarmIsActive=True
+#            print "Mark alarm in array on index:",  data.arrDataIndex-1
+            data.arrData[5][data.arrDataIndex-1]="Alarm"      
+#            print "Add Alarm to array on index:",  data.arrDataIndex-1
+            data.AlarmHour=int(strftime("%H", time.localtime())) #set new alarm to go off now
+            data.AlarmMinute=int(strftime("%M", time.localtime()))
+#            if(data.demo==0): # we are on a N900
+            DeleteAlarm() #delete old alarm if existing
+            print "* Set new Alarm to current time"
+            SetAlarm(data.AlarmHour,  data.AlarmMinute) #set alarm to go off now
+#            else: 
+#                print "Can not set alarm off, Maemo interface not available"
+            return 1
+    else: return 0
+
+
 ###########################################################################
-# Starte the measurement
+# Start the measurement
 ###########################################################################
-def DelayStartMeasurement():
-    global app
-    #init values
+def InitStartMeasurement():
+    global app,  RecordWindowGraph
+    print "initialize all variables..."
     data.sample_index=0
     data.values_total=0
     data.arrDataIndex=0
     data.Note=""
     
-    for i in range(0,  len(data.arrData)): #clear data of old records
-        for j in range(0,  5): data.arrData[j][i]=0
+    for i in range(0, data.arrDataLen): #clear data of old records
+        for j in range(0,  6): data.arrData[j][i]=0
     
     if(data.QuickMode==0):
         data.interval=data.sampling #normal
@@ -175,18 +239,22 @@ def DelayStartMeasurement():
         data.Xscale=0 #set to max zoom level
     
     data.run=1 #change to delayed start
-#    app.timer_GetData = QtCore.QTimer()
-#    QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
-#    app.timer_GetData.start(interval) 
+
 
     app.timer_Delay = QtCore.QTimer()
     QtCore.QObject.connect(app.timer_Delay, QtCore.SIGNAL("timeout()"), StartDelayTimerLoop)     
+    print "QuickMode:",  data.QuickMode
     if(data.QuickMode==1 or data.DelayStartTime==0): #quick mode
         data.DelayStart=0
         app.timer_Delay.start(1) #milliseconds  (make it very quick)
     else:
         data.DelayStart=data.DelayStartTime
         app.timer_Delay.start(1000) #milliseconds         
+        
+    #Set Start times
+#    print "Set StartTime:",  data.StartTime,  data.StartTimeSec
+    data.StartTime=time.localtime()
+    data.StartTimeSec=int(time.mktime(data.StartTime))
    
     data.ChangesInGraph=1 #Make sure it only gets refreshed once    
     RecordWindowGraph.update() #show RecordWindowGraph        
@@ -216,8 +284,12 @@ def StartDelayTimerLoop():
         data.run=2 #change to recording
         
         app.timer_GetData = QtCore.QTimer()
-        QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)        
+        QtCore.QObject.connect(app.timer_GetData, QtCore.SIGNAL("timeout()"), TimerLoop)     
+        
+#        if(data.demo==0): #we are on a N900
         app.timer_GetData.start(data.interval) 
+#        else: #faster in demo mode
+#            app.timer_GetData.start(data.interval/10) 
         
         StartLogfile(data.interval)
         RecordWindow.UpdateScreenStart() 
@@ -231,7 +303,6 @@ def StartDelayTimerLoop():
 
 def StopMeasurement():
     global app
-#    print "Stop timers..."
     if(data.run==1): #in delayed start
         app.timer_Delay.stop()
     elif(data.run==2): #in recording
@@ -239,6 +310,8 @@ def StopMeasurement():
         StopLogfile() 
    
     data.run=0
+#    DeleteAlarm() #delete Alarm if existing
+    data.AlarmIsActive=False
     
     if(data.QuickMode==0): #normal mode
         if(data.OfflineMode=="True" and data.demo!=1): #change to offline mode
@@ -320,6 +393,7 @@ class frmStartWindow(QMainWindow):
         QtCore.QObject.connect(self.ui.bQuick, QtCore.SIGNAL("clicked()"), self.StartMeasurementQuick)
         QtCore.QObject.connect(self.ui.bLog, QtCore.SIGNAL("clicked()"), self.ShowViewWindow)
         QtCore.QObject.connect(self.ui.bConfig, QtCore.SIGNAL("clicked()"), self.ShowConfigWindow)
+        QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
         
         file = open(data.app_path+"Info.htm", 'r')
         txt=""
@@ -340,6 +414,7 @@ class frmStartWindow(QMainWindow):
     # Show the collectring window (hera the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementNormal(self):
+        print "Measure in normal Mode"
         data.QuickMode=0 #run in normal mode
         data.test=0 #show axis lables        
         self.StartMeasurement()
@@ -349,6 +424,7 @@ class frmStartWindow(QMainWindow):
     # Show the collectring window (hera the data gets visualised during the logging)
     ###########################################################################
     def StartMeasurementQuick(self):
+        print "Measure in QuickMode"
         data.QuickMode=1 #run in quick mode (for testing only)
         data.Xscale=0 #default zoom level
         data.test=1 #hide axis lables
@@ -356,17 +432,17 @@ class frmStartWindow(QMainWindow):
         
         
     def StartMeasurement(self):
+#        data.QuickMode=0 #run in normal mode
         global RecordWindowGraph
         RecordWindow.show()
-#        StartWindow.hide()
         RecordWindowGraph = RecordWindowCanvas(RecordWindow)
-        DelayStartMeasurement()
+        InitStartMeasurement()
         RecordWindow.UpdateScreenDelayStart()
         RecordWindowGraph.show()
         
         
     ###########################################################################
-    # Show the log window (her ethe data from a file gets visualised)
+    # Show the log window (where the data from a file gets visualised)
     ###########################################################################
     def ShowViewWindow(self):
         global ViewWindowGraph
@@ -374,10 +450,11 @@ class frmStartWindow(QMainWindow):
         #reset to default log folder
         if(data.demo==1): data.logfolder=data.devlogfolder #folder on devel PC
         else: data.logfolder=data.defaultlogfolder
+        LoadFileList()
         if os.path.exists(data.logfolder+data.lastlogfile):
             data.logfilename=data.lastlogfile
         else:
-            LoadFileList()
+#            LoadFileList()
             l=len(data.arrLogFiles)
             if(l>0):
                 data.logfilename=data.arrLogFiles[l-1] #open last (youngest) log file
@@ -417,6 +494,13 @@ class frmStartWindow(QMainWindow):
 
 
 
+        
+    def SetAlarm(self):
+        AlarmTimeWindow.UpdateScreen()
+        AlarmTimeWindow.show()
+
+
+
 
     def UpdateScreenStart(self):
         try:   
@@ -433,7 +517,7 @@ class frmStartWindow(QMainWindow):
 
     def closeEvent(self, event):
         global config
-        WriteConfig(config)
+        WriteConfig()
 
 
 
@@ -487,13 +571,20 @@ class frmRecordWindow(QMainWindow):
         self.ui.lblSamples_Taken.setText("")
         self.ui.lblElapsedTime.setText("")
         self.ui.lblNote.setText("")
-        self.ui.lblLogfile.setText("")
+#        self.ui.lblLogfile.setText("")
 #        self.ui.lblYscale.setText(str(data.Yscale))
 #        self.ui.lblTrigger.setText(str(data.trigger))
         self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
         self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
         self.ui.bStop.setText("Stop")
 
+        if(data.AlarmIsSet==True): #alarm active
+            m=str(data.AlarmMinute)
+            if(len(m)==1): m="0"+m
+            self.ui.lblAlarmTime.setText(str(data.AlarmHour)+":"+m+" or up to "+str(data.AlarmTimeWindow)+" minutes before that")
+        else: #only recording, no alarm
+            self.ui.lblAlarmTime.setText("(Not set)")
+            
         self.UpdateScreen()
         
         
@@ -505,8 +596,8 @@ class frmRecordWindow(QMainWindow):
 
     def UpdateScreenStart(self):
 #        print "UpdateScreenStart"
-        self.ui.lblLogfile.setText(str(data.logfilename))
-        t= t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
+#        self.ui.lblLogfile.setText(str(data.logfilename))
+        t=strftime("%d. %b. %Y %H:%M:%S", data.StartTime)
         self.ui.lblStarttime.setText(t)
 #        self.ui.lblSamples_Taken.setText("0")
         self.ui.lblElapsedTime.setText("")
@@ -516,7 +607,7 @@ class frmRecordWindow(QMainWindow):
 #        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
 #        self.ui.bStop.setIcon(QIcon(data.app_path+"img/"+"krec2.png"))
 #        self.ui.bStop.setText("Stop recording")
-
+                        
         self.UpdateScreen()
         
         
@@ -531,7 +622,7 @@ class frmRecordWindow(QMainWindow):
         if(data.run==2): #recording
             t=time.mktime(time.localtime())
             time_difference=t-data.StartTimeSec
-            t=strftime("%H:%M:%S", time.gmtime(time_difference))
+            t=strftime("%H:%M:%S", time.localtime(time_difference))
             self.ui.lblElapsedTime.setText(t)
 #        self.ui.lblTrigger.setText(str(data.trigger))
         
@@ -544,7 +635,6 @@ class frmRecordWindow(QMainWindow):
         else: self.ui.bRaiseTrigger.setEnabled(True)
         if(data.trigger==0): self.ui.bLowerTrigger.setEnabled(False)
         else: self.ui.bLowerTrigger.setEnabled(True)
-            
 
 
         
@@ -561,7 +651,7 @@ class frmRecordWindow(QMainWindow):
     def ToggleMeasurement(self):
         global app
         if(data.run==0): #not running
-            DelayStartMeasurement()
+            InitStartMeasurement()
             self.UpdateScreenDelayStart()
         elif(data.run==1): # in delayed start
             StopMeasurement()
@@ -616,6 +706,8 @@ class frmRecordWindow(QMainWindow):
             StopMeasurement()
             self.AskKeepRecord()     
 #        ChangeNoteInFile() #rewrite log file (only do when recording is stopped!)
+        data.AlarmIsSet=False
+        DeleteAlarm() #delete Alarm if existing
         StartWindow.show()
         self.close() 
 
@@ -727,12 +819,12 @@ class frmViewWindow(QMainWindow):
             tt0=time.mktime(t0)
             tt1=time.mktime(t1)+86400*data.MidnightTransitions #correction for Midnight Transitions
     #        print tt0,  tt1,  tt1-tt0
-            d0=strftime("%a. %d.%m.%Y  %H:%M:%S", time.gmtime(tt0))
-            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", time.gmtime(tt1))
-            dt=strftime("%H:%M:%S", time.gmtime(tt1-tt0))
+            d0=strftime("%a. %d.%m.%Y  %H:%M:%S", time.localtime(tt0))
+            d1=strftime("%a. %d.%m.%Y  %H:%M:%S", time.localtime(tt1))
+            dt=strftime("%H:%M:%S", time.localtime(tt1-tt0))
     #        print dt
-            day0=strftime("%a.", time.gmtime(tt0))
-            day1=strftime("%a.", time.gmtime(tt1))
+            day0=strftime("%a.", time.localtime(tt0))
+            day1=strftime("%a.", time.localtime(tt1))
     #        except:
     #            dt=""
     #            day=""         
@@ -763,20 +855,6 @@ class frmViewWindow(QMainWindow):
             
             
                         
-        #scroll bar
-#        Xscale=data.arrXscale[data.Xscale]
-#        Pixels=data.arrDataIndex/Xscale
-##        print Xscale,  Pixels
-#        if(Pixels>775): 
-#            self.ui.SlrScroll.setEnabled(True)
-##            self.ui.SlrScroll.setMaxValue=Pixels-775     
-#        else: 
-#            self.ui.SlrScroll.setEnabled(False)
-#            self.ui.SlrScroll.setValue(0)
-#        self.SliderMoved()
-#        print self.ui.SlrScroll.value()
-
-
         Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
 #        data.GraphStart=min(data.GraphStart+360, max(Pixels-775, 0))
 #        print data.GraphStart
@@ -789,6 +867,7 @@ class frmViewWindow(QMainWindow):
             
 
     def ShowLogFile(self):
+        WriteConfig() #save all parameters as they will get changed
         r=OpenLogFile()    
         if(r==1): #file too long            
             QtGui.QMessageBox.warning(self, 'Record too long!', "The record is too long. The end will be cut off!", QtGui.QMessageBox.Ok)
@@ -798,6 +877,8 @@ class frmViewWindow(QMainWindow):
             return
         elif(r==3): #file is corrupted => draw empty graph
             QtGui.QMessageBox.warning(self, 'File corrupded!', "The data in the record file\n"+data.logfilename+"\nis invalid!\nNo data loaded.", QtGui.QMessageBox.Ok)
+        elif(r==4): #file is empty
+            QtGui.QMessageBox.warning(self, 'File empty!', "The data in the record file\n"+data.logfilename+"\ncontains no data!\nNo data loaded.", QtGui.QMessageBox.Ok)
         LoadFileList()
         ProcessData()
         data.Xscale=1 #default zoom level
@@ -811,12 +892,15 @@ class frmViewWindow(QMainWindow):
         
         
     def NextLogFile(self):
+        Show_passed_time("Next LogFile",  1)
+        
         data.arrLogFileIndex=(data.arrLogFileIndex+1)  % len(data.arrLogFiles)
         data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
         self.ShowLogFile()
 
 
     def LastLogFile(self):
+        Show_passed_time("Last LogFile",   1)
         data.arrLogFileIndex=(data.arrLogFileIndex-1)  % len(data.arrLogFiles)
         data.logfilename=data.arrLogFiles[data.arrLogFileIndex]
         self.ShowLogFile()
@@ -824,6 +908,7 @@ class frmViewWindow(QMainWindow):
 
         
     def ZoomIn(self):
+        Show_passed_time("Zoom in",   1)
         Zoom(+1)
         self.ui.bZoomOut.setEnabled(True)
         if(data.Xscale==0): self.ui.bZoomIn.setEnabled(False)
@@ -835,6 +920,7 @@ class frmViewWindow(QMainWindow):
         self.UpdateScreen()
 
     def ZoomOut(self):
+        Show_passed_time("Zoom out",   1)
         Zoom(-1)
         self.ui.bZoomIn.setEnabled(True)
         if(data.Xscale==data.arrXscaleLen-1): self.ui.bZoomOut.setEnabled(False)
@@ -856,21 +942,12 @@ class frmViewWindow(QMainWindow):
         MoveTrigger(-1)
         self.update()
         self.UpdateScreen()
-        
-        
-#    def SliderMoved(self):
-#        s=self.ui.SlrScroll.value()
-#        Xscale=data.arrXscale[data.Xscale]
-#        Pixels=data.arrDataIndex/Xscale
-#        data.GraphStart=(Pixels-775)*s/100
-#        print s,  data.GraphStart,  Pixels
-#        data.ChangesInGraph=1 #Make sure it only gets refreshed once
-#        self.update()
-#        self.UpdateScreen()
+    
         
         
         
     def goLeft(self):
+        Show_passed_time("Scroll left",   1)
         Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
         data.GraphStart=max(data.GraphStart-600, 0)
 #        print data.GraphStart                
@@ -880,6 +957,7 @@ class frmViewWindow(QMainWindow):
         
         
     def goRight(self):
+        Show_passed_time("Scroll right",   1)
         Pixels=data.arrDataIndex/data.arrXscale[data.Xscale]
         data.GraphStart=min(data.GraphStart+600, max(Pixels-779, 0))
 #        print data.GraphStart        
@@ -935,7 +1013,7 @@ class frmViewWindow(QMainWindow):
     def ShowFileDialog(self):        
         data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
         print "Open file dialog in:",  data.logfolder
-        tmp= QFileDialog.getOpenFileName(None,"Open SleepCycle Log File", data.logfolder, "Log Files (*.csv)");
+        tmp= QFileDialog.getOpenFileName(None,"Open SleepAnalyser Log File", data.logfolder, "Log Files (*.csv)");
         print "Selected file:",  tmp
 #        tmp2=tmp.split("/")
 #        l=len(tmp2)    
@@ -949,9 +1027,10 @@ class frmViewWindow(QMainWindow):
 
 
     def closeEvent(self, event):
-#        config.set('main', 'trigger', str(data.trigger))      
+        LoadConfig() #restore all parameters as they got changed while loading the record file
         ViewWindow.close()
         StartWindow.show()
+        
 
     def EditNote(self):
         r=QInputDialog.getText(None,  "Edit Note",  "Add a note to this record:\n(leave empty for no note)",  QLineEdit.Normal,  data.Note)
@@ -1091,13 +1170,108 @@ class frmDateWindow(QMainWindow):
 
 
 
+###########################################################################
+# Class for Setting the alarm time Window
+###########################################################################
+class frmAlarmTimeWindow(QMainWindow):
+    def __init__(self, parent=None):
+#        QMainWindow.__init__(self, parent)
+        # Notice that you must give a parent window as parameter to the constuctor
+        QMainWindow.__init__(self, parent)
+        # Also set the Stacked Window parameter for every subwindow in the stack
+        if(data.demo==0): self.setAttribute(Qt.WA_Maemo5StackedWindow)
+        
+        self.ui = Ui_AlarmTimeWindow()
+        self.ui.setupUi(self)
+        self.ui.lblIcon.setPixmap(QtGui.QPixmap(data.app_path+"img/"+"SleepAnalyser.png"))
+
+        QtCore.QObject.connect(self.ui.bSetAlarm, QtCore.SIGNAL("clicked()"), self.SetAlarm)
+                
+        if(data.app_path!="./"): #only needed if not started in app path
+            self.ui.bSetAlarm.setIcon(QIcon(data.app_path+"img/"+"SleepAnalyser.png"))
+
+    
+        
+
+    def UpdateScreen(self):
+        if(data.AlarmHour==-1 or data.AlarmMinute==-1):
+            data.AlarmHour=7
+            data.AlarmMinute=0
+        print "Alarm time:",  data.AlarmHour, ":",  data.AlarmMinute
+        self.ui.lstAlarmHour.setCurrentRow(int(data.AlarmHour))
+        self.ui.lstAlarmMinute.setCurrentRow(int(data.AlarmMinute)/5)
+        s="The Alarm will go off on the set time or maximum "+str(data.AlarmTimeWindow)+" minutes earlier, depending on your movements."
+        self.ui.lblNote.setText(s)
+
+        
+        
+
+    def SetAlarm(self):
+        global RecordWindowGraph
+        print "Set Alarm"
+        data.QuickMode=0 #run in normal mode
+        
+        RecordWindowGraph = RecordWindowCanvas(RecordWindow)
+        InitStartMeasurement()
+        
+        try:
+            data.AlarmHour=int(self.ui.lstAlarmHour.currentItem().text())
+            data.AlarmMinute=int(self.ui.lstAlarmMinute.currentItem().text())
+            config.set('main', 'AlarmHour', str(data.AlarmHour))  
+            config.set('main', 'AlarmMinute', str(data.AlarmMinute))  
+        except: #If nothing selected (workaround)
+#            data.AlarmHour=7
+#            data.AlarmMinute=0
+            print "Selected time not valid, use default:",  data.AlarmHour, ":", data.AlarmMinute
+
+        
+        
+        
+        
+        Now=int(strftime("%H", time.localtime()))*3600+int(strftime("%M", time.localtime()))*60 #nows h+m in secs
+        alarm=int(data.AlarmHour)*3600+int(data.AlarmMinute)*60 #alarm h+m in secs
+        alarmdiff=alarm-Now #difference
+        if(alarmdiff<0):  #set to tomorrow if time already is elapsed today
+            alarmdiff=alarmdiff+86400
+            data.AlarmDate=strftime("%d-%m-%Y", time.localtime(time.mktime(time.localtime())+86400))
+        else: #today
+            data.AlarmDate=strftime("%d-%m-%Y", time.localtime())
+        data.AlarmTimeSec=data.StartTimeSec+alarmdiff
+        print "Alarm will be at the "+data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute)+", in:", str(alarmdiff),  "seconds (timestamp "+str(data.AlarmTimeSec)+"). We have now timestamp "+str(data.StartTimeSec)
+
+        
+#        if(data.demo==0): #We are on a N900
+        DeleteAlarm() #delete old alarm if existing
+        SetAlarm(data.AlarmHour,  data.AlarmMinute) #set alarm for the last possible time
+                                #(when movements occure shortly before it, we can set it off earlier.)
+#        else:
+#            print "Can not set alarm, Maemo interface not available"
+        
+        RecordWindow.show()
+        AlarmTimeWindow.hide()
+#        InitStartMeasurement()
+        RecordWindow.UpdateScreenDelayStart()
+        RecordWindowGraph.show()
+
+
+
+    def closeEvent(self, event):        
+        pass
+
+
+
+
+
+
+
+
 ###########################################################################
 # Class for drawing the RecordWindowGraph
 ###########################################################################
 class RecordWindowCanvas(QtGui.QWidget):
     def __init__(self, parent):
         QMainWindow.__init__(self, parent)    
-        self.setGeometry(9, 180, 782, data.Ysize+55)
+        self.setGeometry(9, 185, 782, data.Ysize+55)
     
     def paintEvent(self, event):
         showGraph(self,  QtGui)
