@@ -31,8 +31,8 @@ def StartLogfile(interval):
         
     
     #open file, write header
-    data.StartTime=time.localtime()
-    data.StartTimeSec=time.mktime(data.StartTime)
+#    data.StartTime=time.localtime()
+#    data.StartTimeSec=time.mktime(data.StartTime)
     t=strftime("%Y-%m-%d_%H-%M-%S", data.StartTime)
     data.logfilename="SleepAnalyser_"+t+".csv"
     data.logfile = open(data.logfolder+data.logfilename, 'w')
@@ -41,10 +41,13 @@ def StartLogfile(interval):
     d=strftime("%d-%m-%Y", data.StartTime)
     data.Header=t+"User: "+data.user+", SW version: "+data.version+", Date: " + d + \
             ", Sampling interval: " + str(interval)+" ms, sampling smoothing: " +str(data.sample_smoothing)+ \
-            ", value_smoothing: " + str(data.sample_smoothing )+"\n"
+            ", value_smoothing: " + str(data.sample_smoothing )
+    if(data.AlarmIsSet==True): #only add alarm data if an alarm is set
+        data.Header=data.Header+", Alarm: "+data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute)+", Alarm Time Window: "+str(data.AlarmTimeWindow)
+    data.Header=data.Header+"\n"
     data.logfile.write(data.Header)
     data.logfile.write("Note: \n")
-#    data.Note=""
+
 
 
 
@@ -59,7 +62,8 @@ def StartLogfile(interval):
 def WriteIntoLogFile():
     d=str(data.arrData[0][data.arrDataIndex]) + ", " +  \
         str(data.arrData[1][data.arrDataIndex]) + ", " +  \
-        str(data.arrData[2][data.arrDataIndex])
+        str(data.arrData[2][data.arrDataIndex]) + ", " +  \
+        str(data.arrData[5][data.arrDataIndex])
 
     data.logfile.write(d+"\n")
     if(data.debug==1): print d
@@ -69,7 +73,7 @@ def WriteIntoLogFile():
 ###########################################################################
 #  Close log file
 ###########################################################################
-def StopLogfile():
+def StopLogfile():    
     data.logfile.close()
 
 
@@ -102,6 +106,10 @@ def LoadFileList():
 ###########################################################################
 def OpenLogFile():    
 #    Show_passed_time("OpenLogFile Start")
+
+    for i in range(0, data.arrDataLen): #clear data of old records
+        for j in range(0,  6): data.arrData[j][i]=0
+        
     data.logfolder=string.replace(data.logfolder, "~",  data.homedir) #workaround
     print "Open Log file:",  data.logfolder+data.logfilename
     
@@ -116,7 +124,8 @@ def OpenLogFile():
     ret=0
     try:
         data.Header=file.readline()
-        if(data.debug==1): print "Header:",  data.Header
+#        if(data.debug==1): 
+        print "Header:",  data.Header
         h=string.split(data.Header, ", ")
         x=h[4] #SW version
         SWversion=string.replace(x, "SW version:",  "")
@@ -140,26 +149,76 @@ def OpenLogFile():
             
         x=h[5] #Date
         data.StartDate=string.replace(x, "Date: ",  "")
+        
+        
+        x=h[6] #Interval
+        t=string.replace(x, "Sampling interval: ",  "")
+        data.interval=int(string.replace(t, " ms",  ""))
+        
+        x=h[8] #value_smoothing
+        data.value_smoothing=int(string.replace(x, "value_smoothing: ",  ""))
+        
+        print "Interval:",  data.interval,  ", value_smoothing:",  data.value_smoothing
+        
             
+        if(len(h)>10):  #header includes Alarm data 
+            x=h[9] #get the set Alarm time
+            t=string.replace(x, "Alarm: ",  "")
+            t=string.split(t, " ")
+            data.AlarmDate=t[0]
+            t=string.split(t[1], ":") #time
+            data.AlarmHour=int(t[0])
+            data.AlarmMinute=int(t[1])            
+            
+            x=h[10] #get the set AlarmTimeWindow
+            t=string.replace(x, "Alarm Time Window: ",  "")
+#            t=string.split(t, ":")
+            data.AlarmTimeWindow=int(t)
+
+            data.DelayStartTime=0
+            data.AlarmTimeSec=time.mktime(time.strptime(data.AlarmDate+" "+str(data.AlarmHour)+":"+str(data.AlarmMinute), "%d-%m-%Y %H:%M"))
+            
+            print "Header Alarm time:",  data.AlarmHour,  ":",  data.AlarmMinute,  "AlarmTimeWindow:",  data.AlarmTimeWindow
+        else:
+            data.AlarmHour=-1
+            data.AlarmMinute=-1      
+            
+            
+            
+        
+            
+            
+            
+            
+            
+        Show_passed_time("OpenLogFile: Opened file, loaded header data")
+            
+            
+        #load main data
         data.MidnightTransitions=0
         try:
             for line in file:
     #            print line
-                d=string.split(line,  ", ")
+                d=string.split(line[:-1],  ", ")
+#                print len(d)
                 data.arrData[0][data.arrDataIndex]=d[0] #time
                 data.arrData[1][data.arrDataIndex]=int(d[1]) #X
                 data.arrData[2][data.arrDataIndex]=int(d[2]) #Y
+                try:
+#                    print len(d),  d[0],  d[1],  d[2],  d[3]
+                    if(len(d)>2):
+                        data.arrData[5][data.arrDataIndex]=d[3] #Event
+    #                    print len(d),  d[0],  d[1],  d[2],  d[3],  "----",  data.arrDataIndex,  data.arrData[5][data.arrDataIndex]
+                except:
+                    pass
+                    
                 
-                #check for transitions beond midnight:
-                if(data.arrDataIndex>0): 
-    #                print data.arrDataIndex, data.arrData[0][data.arrDataIndex],  data.arrData[0][data.arrDataIndex-1]
-                    if(data.arrData[0][data.arrDataIndex][:2]=="00" and  data.arrData[0][data.arrDataIndex-1][:2]=="23"):
-                        data.MidnightTransitions=data.MidnightTransitions+1
-    #                    print data.arrDataIndex, "Midnight transition:",  data.MidnightTransitions
-                
+                if(data.arrDataIndex>0): #check for transitions beond midnight:
+                    if(data.arrData[0][data.arrDataIndex][:2]=="00"):
+                        if(data.arrData[0][data.arrDataIndex-1][:2]=="23"): data.MidnightTransitions=data.MidnightTransitions+1                
                 data.arrDataIndex=data.arrDataIndex+1            
                 if(data.arrDataIndex==data.arrDataLen-1): 
-                    print "Stopped, array is full, file is to big"
+                    print "Stopped, array is full, file is to big: ",  data.arrDataIndex,  "Lines"
                     file.close()
                     return 1 #File to long
                     break
@@ -172,7 +231,15 @@ def OpenLogFile():
         file.close()
     
     print "Loaded",  str(data.arrDataIndex),  "lines"
-#    Show_passed_time("OpenLogFile End")
+    
+    if(data.arrDataIndex==0):
+        print "No Data in file"
+        return 4
+    else:
+        data.StartTimeSec=time.mktime(time.strptime(data.StartDate+" "+str(data.arrData[0][0]), "%d-%m-%Y %H:%M:%S"))
+
+        
+    Show_passed_time("OpenLogFile End")
     return 0
     
     
@@ -182,15 +249,15 @@ def OpenLogFile():
 #  Load log file  to change Note (on line 2)
 ###########################################################################
 def ChangeNoteInFile():    
-    print "Reopen log file and add note:",  data.Note
+#    print "Reopen log file and update note:",  data.Note
     file = open(data.logfolder+data.logfilename, 'w')
-    print "Open logfile",  data.logfilename,  ", change Note to\"",  data.Note,  "\" in file",  data.logfilename
+    print "Open logfile",  data.logfilename,  ", change Note to \"",  data.Note,  "\" in file",  data.logfilename
 
     file.write(data.Header)
     file.write("Note: "+data.Note+"\n")
     i=0
     for i in range(0,  data.arrDataIndex):
-        d=str(data.arrData[0][i]) + ", " + str(data.arrData[1][i]) + ", " +  str(data.arrData[2][i])
+        d=str(data.arrData[0][i]) + ", " + str(data.arrData[1][i]) + ", " +  str(data.arrData[2][i]) + ", " +  str(data.arrData[5][i])
         file.write(d+"\n")
     file.close()
     print "Wrote",  i +1,  "lines into file"
@@ -203,6 +270,7 @@ def ChangeNoteInFile():
 ###########################################################################
 def LoadConfig():    
     #get configuration
+    global config
     print "Configuration file:",  data.configfolder+data.ConfigFile
     config = ConfigParser.SafeConfigParser()
 #    if os.path.exists(data.configfolder+data.ConfigFile):
@@ -221,6 +289,8 @@ def LoadConfig():
         data.lastlogfile = config.get('main', 'lastlogfile')
         data.OfflineMode = config.get('main', 'OfflineMode')
         data.DelayStartTime = config.getint('main', 'DelayStartTime')
+        data.AlarmHour = config.getint('main', 'AlarmHour')
+        data.AlarmMinute = config.getint('main', 'AlarmMinute')
         print "Configuration loaded ("+data.ConfigFile+")"
 #    else:
     except: #use default config
@@ -241,17 +311,8 @@ def LoadConfig():
         config.set('main', 'lastlogfile', str(data.lastlogfile))    
         config.set('main', 'OfflineMode', str(data.OfflineMode))      
         config.set('main', 'DelayStartTime', str(data.DelayStartTime))    
-
-    
-    #print usefull data
-#    print "SW version:", data.version
-#    print "Sampling interval:", data.sampling, "ms"
-#    print "sample_smoothing:", data.sample_smoothing, "x"
-#    print "value_smoothing:", data.value_smoothing, "x"
-#    print "=> log interval:", data.sampling*data.value_smoothing/1000, "s"
-#    print "Derivation:", data.derivation, "(substracts value", data.derivation, "- value 0)"  
-#    print "Trigger level:", data.trigger
-#    print "Yscale (for graph only):",  data.Yscale
+        config.set('main', 'AlarmHour', str(data.AlarmHour))    
+        config.set('main', 'AlarmMinute', str(data.AlarmMinute))    
 
     return config
 
@@ -260,7 +321,8 @@ def LoadConfig():
 ###########################################################################
 # Write the configuration into the config file
 ###########################################################################
-def WriteConfig(config):    
+def WriteConfig():    
+        global config
         config.set('main', 'trigger', str(data.trigger))  
         
         f=data.configfolder+data.ConfigFile
